* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Jira Integration](https://help.sap.com/docs/leanix/ea/jira-integration)
  * Importing, Exporting, and Linking Fact Sheets and J…
